#include <Servo.h>
#include <Tlv493d.h>


// Servo objects declaration
Servo servo1,servo2,servo3,servo4;

Tlv493d Tlv493dMagnetic3DSensor = Tlv493d(); // Tlv493d Object
const int switchPin = 8;      // Switch to turn on and off mouse
const int gripperPin = 9; // Switch to turn on and off gripper


int range = 80;               // Output range in mT of X or Y movement
bool armIsActive = false;    // Whether or not to control the arm
int lastSwitchState = LOW;        // Previous switch state
bool gripperIsActive = false;      // Whether or not to control the gripper
int lastGripperState = LOW;         // Previous gripper state


 
void setup() {
  pinMode(switchPin, INPUT);       // Switch pin
  pinMode(LED_BUILTIN, OUTPUT);  // LED pin
  pinMode(gripperPin, INPUT);       // Gripper pin
 
  Serial.begin(9600);    // Start serial monitor
  while(!Serial);        // TL493D Connection
  Tlv493dMagnetic3DSensor.begin();
 
  // Link servo objects to pins
  servo1.attach(2);
  //servo2.attach(3);  //Optional
  servo3.attach(4);
  servo4.attach(5);
 
  // Initialize servos on 0°
  servo1.write(0);
  //servo2.write(0); //Optional
  servo3.write(0);
  servo4.write(0);
}


void loop() {
  //TLV493D Data reading
  Tlv493dMagnetic3DSensor.updateData();
  delay(300);


  //TLV493D Data printing
  Serial.print("X = ");
  Serial.print(Tlv493dMagnetic3DSensor.getY());
  Serial.print(" Y = ");
  Serial.println(Tlv493dMagnetic3DSensor.getX());
  Serial.print(" Z = ");
  Serial.println(Tlv493dMagnetic3DSensor.getZ());


  // Read the switch
  int switchState = digitalRead(switchPin);
  int gripperState = digitalRead(gripperPin);
  // If it's changed and it's high, toggle the mouse state:
  if (switchState != lastSwitchState) {
    if (switchState == HIGH) {
      armIsActive = !armIsActive;
      // Turn on LED to indicate mouse state:
      digitalWrite(LED_BUILTIN, !armIsActive);
    }
  }
  // Save switch state for next comparison
  lastSwitchState = switchState;




  // Read and scale the two axes
  int xReading =   map(constrain((int)Tlv493dMagnetic3DSensor.getY(),0,range),0,range,0,180);
  int yReading = map(constrain((int)Tlv493dMagnetic3DSensor.getX(),0,range),0,range,0,180);

 // if the mouse control state is active, move the mouse:
  if (armIsActive) {
    servo1.write(xReading);
    //servo2.write(zReading);
    servo3.write(yReading);


      // Read the gripper
    if (gripperState != lastGripperState) {
          if (gripperState == HIGH) {
            gripperIsActive = !gripperIsActive;
            // Open or close the gripper
            if(gripperIsActive==true)
                  servo4.write(180);
            else
              servo4.write(0);
          }
    }
  // Save gripper state for next comparison
  lastGripperState = gripperState;
  }
}
